@@ -16,7 +16,6 @@ class QuickbooksTransactionEntity(QuickbooksBaseObject):
         self.SyncToken = 0
         self.sparse = False
         self.domain = "QBO"
-        self.TxnDate = ""
 
 
 class QuickbooksManagedObject(QuickbooksBaseObject, ReadMixin, ListMixin, UpdateMixin):
@@ -129,10 +128,10 @@ class LinkedTxn(QuickbooksBaseObject):
 class CustomerMemo(QuickbooksBaseObject):
     def __init__(self):
         super(CustomerMemo, self).__init__()
-        self.Value = ""
+        self.value = ""
 
     def __str__(self):
-        return self.Value
+        return self.value
 
 
 class MarkupInfo(QuickbooksBaseObject):
