@@ -8,7 +8,7 @@ class CustomerTests(unittest.TestCase):
         customer = Customer()
         customer.DisplayName = "test"
 
-        self.assertEquals(unicode(customer), "test")
+        self.assertEquals(str(customer), "test")
 
     def test_to_ref(self):
         customer = Customer()
